@@ -8,6 +8,7 @@
 #endif /* HAVE_CONFIG_H */
 
 #include "about.h"
+#include "i18n.h"
 
 static GtkWidget *wi = NULL;
 
@@ -42,15 +43,15 @@ about_event(GtkWidget *widget, gpointer data)
   gtk_signal_connect(GTK_OBJECT(wi), "delete_event",
                      GTK_SIGNAL_FUNC(delete_event), NULL); 
 
-  gtk_window_set_wmclass(GTK_WINDOW(wi), "about", "Geg");
-  gtk_window_set_title(GTK_WINDOW(wi), "About geg");
+  gtk_window_set_wmclass(GTK_WINDOW(wi), _("about"), "Geg");
+  gtk_window_set_title(GTK_WINDOW(wi), _("About geg"));
   gtk_window_set_policy(GTK_WINDOW(wi), FALSE, FALSE, FALSE);
   gtk_window_position(GTK_WINDOW(wi), GTK_WIN_POS_CENTER);
 
   gtk_container_border_width(GTK_CONTAINER(GTK_DIALOG(wi)->vbox), 5);
 
   /* ok button */
-  bu = gtk_button_new_with_label("Ok");
+  bu = gtk_button_new_with_label(_("Ok"));
   gtk_signal_connect(GTK_OBJECT(bu), "clicked",
                      GTK_SIGNAL_FUNC(ok_event), NULL);
 
