@@ -4,7 +4,8 @@
 #include <gtk/gtk.h>
 
 void create_log(GtkWidget *widget);
-void write_log(GtkWidget *widget, gchar *message);
+void write_log(gchar *message);
+void addto_log(gchar *message);
 void clear_log(GtkWidget *widget, gpointer data);
 
 #endif /* __LOG_H__ */
